DatabaseStore

Struct DatabaseStore 

pub struct DatabaseStore<R: Runtime> {
    pub key: Bytes,
    pub payload: DatabaseStorePayload,
    pub reply: ReplyType,
    /* private fields */
}
Database store message.

Fields

key: Bytes

Search key.

payload: DatabaseStorePayload

Payload contained within the DatabaseStore message.

reply: ReplyType

Reply type.

Implementations

Source

impl<R: Runtime> DatabaseStore<R>

pub fn parse_frame( input: &[u8], ) -> IResult<&[u8], Self, DatabaseStoreParseError>

Attempt to parse DatabaseStore from input.

Returns the parsed message and rest of input on success.

pub fn parse(input: &[u8]) -> Result<Self, DatabaseStoreParseError>

Attempt to parse input into DatabaseStore.

pub fn extract_raw_lease_set(input: &[u8]) -> Bytes

Extract raw, unserialized [LeaseSet] from input.

Caller is expected to ensure that input is a valid DatabaseStore that contains a valid LeaseSet2.

pub fn extract_raw_router_info(input: &[u8]) -> Bytes

Extract raw, unserialized RouterInfo from input.

Caller is expected to ensure that input is a valid DatabaseStore that contains a valid RouterInfo.