pub struct DatabaseStore<R: Runtime> {
pub key: Bytes,
pub payload: DatabaseStorePayload,
pub reply: ReplyType,
/* private fields */
}Expand description
Database store message.
Fields
key: BytesSearch key.
payload: DatabaseStorePayloadPayload contained within the DatabaseStore message.
reply: ReplyTypeReply type.
Implementations
Sourceimpl<R: Runtime> DatabaseStore<R>
impl<R: Runtime> DatabaseStore<R>
Sourcepub fn parse_frame(
input: &[u8],
) -> IResult<&[u8], Self, DatabaseStoreParseError>
pub fn parse_frame( input: &[u8], ) -> IResult<&[u8], Self, DatabaseStoreParseError>
Attempt to parse DatabaseStore from input.
Returns the parsed message and rest of input on success.
Sourcepub fn parse(input: &[u8]) -> Result<Self, DatabaseStoreParseError>
pub fn parse(input: &[u8]) -> Result<Self, DatabaseStoreParseError>
Attempt to parse input into DatabaseStore.
Sourcepub fn extract_raw_lease_set(input: &[u8]) -> Bytes
pub fn extract_raw_lease_set(input: &[u8]) -> Bytes
Extract raw, unserialized [LeaseSet] from input.
Caller is expected to ensure that input is a valid DatabaseStore that contains
a valid LeaseSet2.
Sourcepub fn extract_raw_router_info(input: &[u8]) -> Bytes
pub fn extract_raw_router_info(input: &[u8]) -> Bytes
Extract raw, unserialized RouterInfo from input.
Caller is expected to ensure that input is a valid DatabaseStore that contains
a valid RouterInfo.